Skip to contents

Loads a model bundle written by save_pixel_model and reconstructs the complete object expected by apply_pixel_model.

Usage

load_pixel_model(path)

Arguments

path

Character. Directory containing a saved pixel model bundle.

Value

A trained pixel model list with the Keras network and its R metadata.

See also