Skip to contents

Generates artificial landscapes with defined spatial patterns, calculates landscape metrics, and trains neural networks to classify landscape patterns.

The package supports two classification workflows:

  • Pixel-based classification with convolutional neural networks using keras3 (see train_pixel_model)

  • Metrics-based classification with landscape metrics from landscapemetrics as neural-network inputs (see train_metric_model)

Typical workflow

  1. Generate training landscapes with create_landscapes

  2. Optionally calculate and evaluate landscape metrics with calculate_metrics and evaluate_metrics

  3. Train a classifier with train_pixel_model or train_metric_model

  4. Apply the trained model to new landscapes with apply_pixel_model or apply_metric_model

  5. Visualize results with plot_classified_landscapes

References

Tietjen, B., Baldauf, S., & Berger, U. (2026). patternscaper: An R package for classifying spatial landscape patterns using neural networks. *Methods in Ecology and Evolution*. In review.

Author

Maintainer: Selina Baldauf selina.baldauf@fu-berlin.de (ORCID)

Authors: