patternscaper: Classify Spatial Landscape Patterns Using Neural Networks
Source:R/patternscaper.R
patternscaper.RdGenerates artificial landscapes with defined spatial patterns, calculates landscape metrics, and trains neural networks to classify landscape patterns.
The package supports two classification workflows:
Pixel-based classification with convolutional neural networks using keras3 (see
train_pixel_model)Metrics-based classification with landscape metrics from landscapemetrics as neural-network inputs (see
train_metric_model)
Typical workflow
Generate training landscapes with
create_landscapesOptionally calculate and evaluate landscape metrics with
calculate_metricsandevaluate_metricsTrain a classifier with
train_pixel_modelortrain_metric_modelApply the trained model to new landscapes with
apply_pixel_modelorapply_metric_modelVisualize results with
plot_classified_landscapes
References
Tietjen, B., Baldauf, S., & Berger, U. (2026). patternscaper: An R package for classifying spatial landscape patterns using neural networks. *Methods in Ecology and Evolution*. In review.
Author
Maintainer: Selina Baldauf selina.baldauf@fu-berlin.de (ORCID)
Authors:
Selina Baldauf selina.baldauf@fu-berlin.de (ORCID)
Britta Tietjen britta.tietjen@fu-berlin.de (ORCID)
Uta Berger uta.berger@tu-dresden.de (ORCID)